from earthdiagnostics import Utils, cdftools
from log import Log
from nco import NCOException
import os
import shutil


class Circulation(object):

    @staticmethod
    def moc(input_file, output_file):
        """
        Compute the MOC for oceanic basins
        Created in March 2012
        Author : vguemas@ic3.cat

        :param input_file:  input grid_V file name
        :type input_file: str
        :param output_file: output file name (=> 2D, depth-y)
        :param output_file: str
        :return:
        """
        nco = Utils.nco
        if os.path.exists(output_file):
            os.remove(output_file)

        cdftools.run('cdfmoc', input=input_file, output=output_file)
        nco.ncwa(input=output_file, output=output_file, options='-O -a x')
        nco.ncks(input=output_file, output=output_file, options='-O -x -v nav_lon,nav_lat')

        Utils.rename_variable(output_file, 'time_counter', 'time', False, True)
        Utils.rename_variable(output_file, 'gsize', 'y', False)

        temp = Utils.get_temp_file()
        shutil.copy(input_file, temp)
        Utils.rename_variable(output_file, 'time_counter', 'time', False, True)

        nco.ncks(input=input_file, output=output_file, options='-A -v nav_lon,nav_lat')

    @staticmethod
    def psi(input_file_u, input_file_v, output_file):
        """
        Compute the barotropic stream function

        Created in March 2012         Author : vguemas@ic3.cat
        :param input_file_u: input grid_U file name
        :rtype input_file_U: str
        :param input_file_v: input grid_V file name
        :rtype input_file_V: str
        :param output_file: output file name without nc extension  (=> 2D x-y)
        :rtype output_file: str
        """
        integrated_u = Utils.get_temp_file()
        integrated_v = Utils.get_temp_file()
        cdftools.run('cdfpsi', input=[input_file_u, input_file_v], output=integrated_u, )
        cdftools.run('cdfpsi', input=[input_file_u, input_file_v], output=integrated_v, options='V')

        Utils.nco.ncea(input=[integrated_u, integrated_v], output=output_file)
        Utils.rename_variable(output_file, 'time_counter', 'time', False, True)


def main():
    try:
        Circulation.psi("ORCA1_MM_19601101_19610228_grid_U.nc", "ORCA1_MM_19601101_19610228_grid_V.nc", "out_psi.nc")
        Circulation.moc("ORCA1_MM_19601101_19610228_grid_V.nc", "out_moc.nc")
    except NCOException as ex:
        Log.error('Exception {0}: stderr: {1}, stdout: {2}',  ex.msg, ex.stderr, ex.stdout)
    Utils.clean()


if __name__ == "__main__":
    main()